@@ -60,9 +60,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     app.setOrganizationName(QStringLiteral("Maui"));
     app.setWindowIcon(QIcon(":/index.png"));
 
-    MauiApp::instance()->setIconName("qrc:/assets/index.svg");
-
-    KLocalizedString::setApplicationDomain("index");
+    KLocalizedString::setApplicationDomain("index-fm");
 
     KAboutData about(QStringLiteral("index"), i18n("Index"), INDEX_VERSION_STRING, i18n("Browse, organize and preview your files."),
                      KAboutLicense::LGPL_V3, i18n("© 2019-%1 Maui Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
@@ -74,10 +72,17 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     about.setBugAddress("https://invent.kde.org/maui/index-fm/-/issues");
     about.setOrganizationDomain(INDEX_URI);
     about.setProgramLogo(app.windowIcon());
+    about.addComponent("KIO");
 
     KAboutData::setApplicationData(about);
+    MauiApp::instance()->setIconName("qrc:/assets/index.png");
+
+    QCommandLineOption newWindowOption(QStringList() << "n" << "new", "Open url in a new window.", "url");
 
     QCommandLineParser parser;
+
+    parser.addOption(newWindowOption);
+
     parser.setApplicationDescription(about.shortDescription());
     parser.process(app);
     about.processCommandLine(&parser);
@@ -91,7 +96,16 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
             paths << QUrl::fromUserInput(path).toString();
     }
 
+
 #if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
+
+
+    if(parser.isSet(newWindowOption))
+    {
+        paths = QStringList() << QUrl::fromUserInput(parser.value(newWindowOption)).toString() ;
+    }else
+    {
+
     if (IndexInstance::attachToExistingInstance(QUrl::fromStringList(paths), false, false))
     {
         // Successfully attached to existing instance of Dolphin
@@ -105,10 +119,11 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 //            instances.first().first->activateWindow();
 //        }
     }
+    }
 
     IndexInstance::registerService();
 #endif
-    Index *index = new Index();
+    auto index = std::make_unique<Index>();
 
     QQmlApplicationEngine engine;
     const QUrl url(QStringLiteral("qrc:/main.qml"));
@@ -116,7 +131,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
                 &engine,
                 &QQmlApplicationEngine::objectCreated,
                 &app,
-                [url, index](QObject *obj, const QUrl &objUrl) {
+                [url, &index](QObject *obj, const QUrl &objUrl) {
         if (!obj && url == objUrl)
             QCoreApplication::exit(-1);
 
@@ -124,9 +139,11 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     }, Qt::QueuedConnection);
 
+    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
+
     engine.rootContext()->setContextProperty("initPaths", paths);
 
-    engine.rootContext()->setContextProperty("inx", index);
+    engine.rootContext()->setContextProperty("inx", index.get());
     qmlRegisterType<CompressedFile>(INDEX_URI, 1, 0, "CompressedFile");
     qmlRegisterType<FilePreviewer>(INDEX_URI, 1, 0, "FilePreviewProvider");
     qmlRegisterType<RecentFilesModel>(INDEX_URI, 1, 0, "RecentFiles");
